@@ -1,4 +1,5 @@
-from typing import Any, Dict, List, Tuple, Type
+import warnings
+from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Type
 
 import duckdb
 from sqlalchemy import types as sqltypes
@@ -7,15 +8,24 @@ from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
 from sqlalchemy.dialects.postgresql.base import PGExecutionContext, PGInspector
 from sqlalchemy.engine.url import URL
 
-name = "duckdb"  # TODO: find if sqlalchemy documents this field anywhere
+__version__ = "0.2.0"
+
+if TYPE_CHECKING:
+    from sqlalchemy.sql.ddl import ExecutableDDLElement  # type: ignore
 
 
 class DBAPI:
-    paramstyle = "qmark"
+    paramstyle = duckdb.paramstyle
+    apilevel = duckdb.apilevel
+    threadsafety = duckdb.threadsafety
 
     class Error(Exception):
         pass
 
+    @staticmethod
+    def Binary(x: Any) -> Any:
+        return x
+
 
 class DuckDBInspector(PGInspector):
     def get_check_constraints(
@@ -97,11 +107,40 @@ class ConnectionWrapper:
                 raise e
 
 
+class DuckDBEngineWarning(Warning):
+    pass
+
+
+class DuckDBEngineCommentWarning(DuckDBEngineWarning):
+    pass
+
+
+def remove_comments(ddl: "ExecutableDDLElement") -> None:
+    # TODO: swap these attribute checks for type checks
+    if hasattr(ddl, "element"):
+        remove_comments(ddl.element)
+    elif hasattr(ddl, "elements"):
+        for el in ddl.elements:
+            remove_comments(el)
+    elif hasattr(ddl, "columns"):
+        for col in ddl.columns:
+            remove_comments(col)
+
+    if hasattr(ddl, "comment") and ddl.comment:
+        ddl.comment = None
+        warnings.warn(
+            "Stripping a comment, as duckdb does not support them",
+            category=DuckDBEngineCommentWarning,
+        )
+
+
 class Dialect(postgres_dialect):
     name = "duckdb"
+    driver = "duckdb_engine"
     _has_events = False
     identifier_preparer = None
     supports_statement_cache = False
+    supports_sane_rowcount = False
     inspector = DuckDBInspector
     # colspecs TODO: remap types to duckdb types
     colspecs = util.update_copy(
@@ -110,6 +149,7 @@ class Dialect(postgres_dialect):
             # the psycopg2 driver registers a _PGNumeric with custom logic for
             # postgres type_codes (such as 701 for float) that duckdb doesn't have
             sqltypes.Numeric: sqltypes.Numeric,
+            sqltypes.Interval: sqltypes.Interval,
         },
     )
 
@@ -124,12 +164,15 @@ class Dialect(postgres_dialect):
         pass
 
     def ddl_compiler(
-        self, dialect: str, ddl: Any, **kwargs: Any
+        self,
+        dialect: str,
+        ddl: "ExecutableDDLElement",
+        **kwargs: Any,
     ) -> postgres_dialect.ddl_compiler:
         # TODO: enforce no `serial` type
 
-        # duckdb doesn't support foreign key constraints (yet)
-        ddl.include_foreign_key_constraints = {}
+        remove_comments(ddl)
+
         return postgres_dialect.ddl_compiler(dialect, ddl, **kwargs)
 
     def do_execute(
@@ -195,6 +238,3 @@ class Dialect(postgres_dialect):
         rs = connection.exec_driver_sql(s)
 
         return [row[0] for row in rs]
-
-
-dialect = Dialect
