@@ -1,4 +1,6 @@
+import zlib
 from datetime import timedelta
+from typing import Any, Optional
 
 from hypothesis import assume, given, settings
 from hypothesis.strategies import text
@@ -14,6 +16,8 @@ from sqlalchemy import (
     Table,
     create_engine,
     inspect,
+    select,
+    types,
 )
 from sqlalchemy.dialects import registry
 from sqlalchemy.dialects.postgresql.base import PGInspector
@@ -21,6 +25,8 @@ from sqlalchemy.engine import Engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import RelationshipProperty, Session, relationship, sessionmaker
 
+from .conftest import raises_msg
+
 
 @fixture
 def engine() -> Engine:
@@ -34,6 +40,29 @@ def engine() -> Engine:
 Base = declarative_base()
 
 
+class CompressedString(types.TypeDecorator):
+    """Custom Column Type"""
+
+    impl = types.BLOB
+
+    def process_bind_param(self, value: Optional[str], dialect: Any) -> Optional[bytes]:  # type: ignore
+        if value is None:
+            return None
+        return zlib.compress(value.encode("utf-8"), level=9)
+
+    def process_result_value(self, value: bytes, dialect: Any) -> str:  # type: ignore
+        return zlib.decompress(value).decode("utf-8")
+
+
+class TableWithBinary(Base):
+
+    __tablename__ = "table_with_binary"
+
+    id = Column(Integer(), Sequence("id_seq"), primary_key=True)
+
+    text = Column(CompressedString())
+
+
 class FakeModel(Base):
     __tablename__ = "fake"
 
@@ -190,7 +219,6 @@ def test_description() -> None:
     duckdb.connect("").description
 
 
-@mark.xfail(reason="support not released", raises=RuntimeError)
 def test_intervals(session: Session) -> None:
     session.add(IntervalModel(field=timedelta(days=1)))
     session.commit()
@@ -198,3 +226,39 @@ def test_intervals(session: Session) -> None:
     owner = session.query(IntervalModel).one()  # act
 
     assert owner.field == timedelta(days=1)
+
+
+def test_binary(session: Session) -> None:
+
+    a = TableWithBinary(text="Hello World!")
+    session.add(a)
+    session.commit()
+
+    b: TableWithBinary = session.scalar(select(TableWithBinary))  # type: ignore
+    assert b.text == "Hello World!"
+
+
+@raises_msg("syntax error")
+def test_comment_support() -> None:
+    "comments not yet supported by duckdb"
+    import duckdb
+
+    duckdb.default_connection.execute('comment on sqlite_master is "hello world";')
+
+
+@mark.xfail(raises=AttributeError)
+def test_rowcount() -> None:
+    import duckdb
+
+    duckdb.default_connection.rowcount
+
+
+def test_sessions(session: Session) -> None:
+    c = IntervalModel(field=timedelta(seconds=5))
+    session.add(c)
+    session.commit()
+
+    c = session.get(IntervalModel, 1)  # type: ignore
+    c.field = timedelta(days=5)
+    session.flush()
+    session.commit()
